@@ -2,7 +2,7 @@
 """Data parsing for KEGG
 
 This module handles the retrieval of data from KEGG into a local directory.
-The possible type of data that can be download:
+The possible type of data that can be downloaded:
 
 - Metabolite: Identifiers that start with the letter C, e.g C00001
 - Reactions: Identifiers that start with the letter R, e.g R00001. The
@@ -15,6 +15,7 @@ Important class of the module:
 - KeggParser: Child of the abstract class
 :class:`cobramod.parsing.base.BaseParser`.
 """
+import io
 from contextlib import suppress
 from itertools import chain
 from pathlib import Path
@@ -28,6 +29,23 @@ from cobramod.parsing.base import BaseParser
 from cobramod.error import WrongParserError, AbbreviationWarning
 
 
+def _kegg_info_to_version(info: str) -> str:
+    with io.StringIO(info) as lines:
+        for num, line in enumerate(lines, 1):
+            if num == 2:
+                return line[line.find("Release") + 8 :].rstrip()
+
+    msg = (
+        "Error determining the kegg version. "
+        'Instead, "Undefined" is used as version.'
+    )
+    warn(
+        message=msg,
+        category=UserWarning,
+    )
+    return "Undefined"
+
+
 def _get_keys(raw: str) -> Generator:
     """
     Returns as Generator the keys for KEGG data. Input is raw text
@@ -503,7 +521,7 @@ class KeggParser(BaseParser):
         Returns:
             dict: relevant data for given identifier
         """
-        KeggParser._check_database(database=database)
+        KeggParser._check_database(directory=directory, database=database)
         raw = retrieve_data(directory=directory, identifier=identifier)
         debug_log.log(
             level=debug_level,
@@ -517,7 +535,7 @@ class KeggParser(BaseParser):
         return KeggParser._parse(root=raw, directory=directory, genome=genome)
 
     @staticmethod
-    def _check_database(database: str):
+    def _check_database(directory: Path, database: str):
         """
         Returns the name of the database. This method is used to compare with
         given database name. It will raise a warning if both names are not
@@ -564,7 +582,6 @@ def retrieve_data(directory: Path, identifier: str) -> dict:
     if directory.exists():
         database = "KEGG"
         data_dir = directory.joinpath(database)
-        data_dir.mkdir(exist_ok=True)
         filename = data_dir.joinpath(f"{identifier}.txt")
         debug_log.debug(f'Searching "{identifier}" in directory "{database}".')
         # Try to obtain the data locally or get it from KEGG and store it
@@ -581,10 +598,21 @@ def retrieve_data(directory: Path, identifier: str) -> dict:
             try:
                 r.raise_for_status()
                 unformatted_data = r.text
+
+                database_version = get("http://rest.kegg.jp/info/kegg")
+                database_version.raise_for_status()
+                database_version = database_version.text
+                database_version = _kegg_info_to_version(database_version)
+
+                BaseParser.check_database_version(
+                    directory, "kegg", database_version
+                )
+
                 debug_log.info(
                     f'Object "{identifier}" found in database. Saving in '
                     f'directory "{database}".'
                 )
+                data_dir.mkdir(exist_ok=True)
                 with open(file=filename, mode="w+") as file:
                     file.write(unformatted_data)
                 # Search for the gene information and store it if found.
